@@ -1,8 +1,8 @@
 from typing import Type
-
 from pydantic import BaseModel, Field
 from pymultirole_plugins.formatter import FormatterBase, FormatterParameters
 from pymultirole_plugins.schema import Document
+from starlette.responses import Response
 
 
 class RFXmlParameters(FormatterParameters):
@@ -14,7 +14,7 @@ class RFXmlFormatter(FormatterBase):
     """
 
     def format(self, document: Document, parameters: FormatterParameters) \
-            -> str:
+            -> Response:
         """Parse the input source file and return a list of documents.
 
         :param source: A file object containing the data.
@@ -31,7 +31,7 @@ class RFXmlFormatter(FormatterBase):
             You'll have to use soap here.
         </Body>
         </shampoo>"""
-        return data
+        return Response(content=data, media_type="application/xml")
 
     @classmethod
     def get_model(cls) -> Type[BaseModel]:
